# Port_reader eklentisi

port_reader eklentisi paralel ya da seri bağlantı noktası gibi rastgele bir bağlantı noktasından girdileri okur ve katılımcının yanıtını cevap olarak geri getiri (örneğin, bir tuşa basılması).

- **Dummy mode** -- 'yes' (evet) olarak ayarlandığında klavye kullanılır. Test yapma amacı için kullanışlıdır.
- **Port number** -- Kullanılmak istenen bağlantı noktası sayısını gösterir.
- **Resting-state value** -- Buradaki değer 'hiç bir tuşa basılmadı' şeklinde yorumlanmalıdır.
- **Correct response** -- Beklenen yanıt.
- **Timeout** -- Tepki için maksimum süre, eğer bu sürede katılımcı tepki/yanıt vermezse zaman aşımı sinyali gönderilir.
